@@ -80,16 +80,17 @@ mob <- function(formula, weights, data = list(),
 
   ## package into return object
   rval <- new("mob", tree = tr, 
-    responses = initVariableFrame(formula@get("response"), trafo = NULL),
+    responses = initVariableFrame(formula@get("response"), trafo = NULL, response = TRUE),
     data = formula)
   return(rval)
 }
 
 ## control splitting parameters
-mob_control <- function(alpha = 0.05, bonferroni = TRUE, minsplit = 20, objfun = deviance,
-  breakties = FALSE, verbose = FALSE)
+mob_control <- function(alpha = 0.05, bonferroni = TRUE, minsplit = 20, trim = 0.1,
+  objfun = deviance, breakties = FALSE, verbose = FALSE)
 {
   rval <- list(alpha = alpha, bonferroni = bonferroni, minsplit = minsplit,
+               trim = ifelse(is.null(trim), minsplit, trim),
                objfun = objfun, breakties = breakties, verbose = verbose)
   class(rval) <- "mob_control"
   return(rval)
