@@ -3,7 +3,7 @@
     Node computations
     *\file Node.c
     *\author $Author: hothorn $
-    *\date $Date: 2007-01-15 11:24:41 +0100 (Mon, 15 Jan 2007) $
+    *\date $Date: 2007-02-02 11:22:45 +0100 (Fri, 02 Feb 2007) $
 */
                 
 #include "party.h"
@@ -53,7 +53,7 @@ void C_Node(SEXP node, SEXP learnsample, SEXP weights,
     double *teststat, *pvalue, smax, cutpoint = 0.0, maxstat = 0.0;
     double *standstat, *splitstat;
     SEXP responses, inputs, x, expcovinf, thisweights, linexpcov;
-    SEXP varctrl, splitctrl, gtctrl, tgctrl, split, jointy;
+    SEXP varctrl, splitctrl, gtctrl, tgctrl, split, testy, predy;
     double *dxtransf, *dweights;
     int *itable;
     
@@ -66,8 +66,9 @@ void C_Node(SEXP node, SEXP learnsample, SEXP weights,
     mincriterion = get_mincriterion(gtctrl);
     responses = GET_SLOT(learnsample, PL2_responsesSym);
     inputs = GET_SLOT(learnsample, PL2_inputsSym);
-    jointy = get_jointtransf(responses);
-    q = ncol(jointy);
+    testy = get_test_trafo(responses);
+    predy = get_predict_trafo(responses);
+    q = ncol(testy);
 
     /* <FIXME> we compute C_GlobalTest even for TERMINAL nodes! </FIXME> */
 
@@ -85,7 +86,7 @@ void C_Node(SEXP node, SEXP learnsample, SEXP weights,
 
     /* <FIXME> feed raw numeric values OR dummy encoded factors as y 
        Problem: what happens for survival times ? */
-    C_prediction(REAL(jointy), nobs, q, REAL(weights), 
+    C_prediction(REAL(predy), nobs, ncol(predy), REAL(weights), 
                      sweights, dprediction);
     /* </FIXME> */
 
@@ -133,7 +134,7 @@ void C_Node(SEXP node, SEXP learnsample, SEXP weights,
                     splitstat = REAL(get_splitstatistics(fitmem));
                 }
 
-                C_split(REAL(x), 1, REAL(jointy), q, REAL(weights), nobs,
+                C_split(REAL(x), 1, REAL(testy), q, REAL(weights), nobs,
                         INTEGER(get_ordering(inputs, jselect)), splitctrl, 
                         GET_SLOT(fitmem, PL2_linexpcov2sampleSym),
                         expcovinf, REAL(S3get_splitpoint(split)), &maxstat,
@@ -169,7 +170,7 @@ void C_Node(SEXP node, SEXP learnsample, SEXP weights,
  
                  C_splitcategorical(INTEGER(x), 
                                     LENGTH(get_levels(inputs, jselect)), 
-                                    REAL(jointy), q, REAL(weights), 
+                                    REAL(testy), q, REAL(weights), 
                                     nobs, standstat, splitctrl, 
                                     GET_SLOT(fitmem, PL2_linexpcov2sampleSym),
                                     expcovinf, &cutpoint, 
@@ -231,7 +232,7 @@ SEXP R_Node(SEXP learnsample, SEXP weights, SEXP fitmem, SEXP controls) {
      PROTECT(ans = allocVector(VECSXP, NODE_LENGTH));
      C_init_node(ans, get_nobs(learnsample), get_ninputs(learnsample), 
                  get_maxsurrogate(get_splitctrl(controls)),
-                 ncol(get_jointtransf(GET_SLOT(learnsample, PL2_responsesSym))));
+                 ncol(get_predict_trafo(GET_SLOT(learnsample, PL2_responsesSym))));
 
      C_Node(ans, learnsample, weights, fitmem, controls, 0);
      UNPROTECT(1);
