@@ -3,7 +3,7 @@
     Random forest with conditional inference trees
     *\file RandomForest.c
     *\author $Author: hothorn $
-    *\date $Date: 2007-01-15 11:24:41 +0100 (Mon, 15 Jan 2007) $
+    *\date $Date: 2007-02-02 11:22:45 +0100 (Fri, 02 Feb 2007) $
 */
 
 #include "party.h"
@@ -60,7 +60,7 @@ SEXP R_Ensemble(SEXP learnsample, SEXP weights, SEXP fitmem, SEXP controls) {
      
          C_init_node(tree, nobs, get_ninputs(learnsample), 
                      get_maxsurrogate(get_splitctrl(controls)),
-                     ncol(get_jointtransf(GET_SLOT(learnsample, 
+                     ncol(get_predict_trafo(GET_SLOT(learnsample, 
                                                    PL2_responsesSym))));
 
          /* generate altered weights for perturbation */
